aind\_data\_schema.ephys package
================================

Submodules
----------

aind\_data\_schema.ephys.ephys\_rig module
------------------------------------------

.. automodule:: aind_data_schema.ephys.ephys_rig
   :members:
   :undoc-members:
   :show-inheritance:

aind\_data\_schema.ephys.ephys\_session module
----------------------------------------------

.. automodule:: aind_data_schema.ephys.ephys_session
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_data_schema.ephys
   :members:
   :undoc-members:
   :show-inheritance:
